%% Calibration and solution of the model

%% Typical parameter values to be used in calibrations
p = struct();

p.c1 = 1;
p.c2 = 0.5;

%% 1. Aggregate demand equation
% L_GDP_GAP = b1*L_GDP_GAP{-1} - b2*MCI + b3*L_GDP_RW_GAP + SHK_L_GDP_GAP
% MCI = b4*RR_GAP + (1-b4)*(-L_Z_GAP);

% b1 - Output persistence (habit formation in households' decisions) varies between 0.1 (extremely flexible) and 0.95
% (extremely persistent)
p.b1 = 0.7; %%0.4;

% b2 - Policy passthrough (impact of monetary policy on real economy) varies
% between 0.1 (relatively low impact) to 0.5 (strong impact)
p.b2 = 0.1;

% b3 - External demand impact varies between 0.1 and 0.6
p.b3 = 0.15;

% b4 - Weight of real interest rate and real exchange rate in monetary
% conditions a4 varies from 0.3 to 0.8
p.b4 = 0.6; %% 0.6;

%% 2. Aggregate supply equation (Phillips curve)
% DLA_CPI =  a1*DLA_CPI{-1} + (1-a1)*DLA_CPI{+1} + a2*RMC + SHK_DLA_CPI
% RMC = a3*L_GDP_GAP + (1-a3)*L_Z_GAP

% Inflation persistence -- a weight on forward and backward looking part;
% a1 varies between 0.4 (low persistence) to 0.9
% (high persistence).
p.a1 = 0.5;

% policy passthrough (impact of output gap on inflation) and inflation persistence; 
% a2 varies between 0.1  (a flat Phillips curve and high sacrifice ratio) to 0.5 (steep Phillips
% curve and low sacrifice ratio)
p.a2 = 0.2; 

% (1-b3) is a ratio of imported non-oil goods in firms marginal costs; b3 varies between 0.1 for
% highly closed economy to 0.5 for an open economy
p.a3 = 0.5;

%% 4. Uncovered Interest Rate Parity
% UIP with partly backward-looking element 
% L_S = (1-e1)*L_S{+1} + e1*(L_S{-1} + 2/4*(D4L_CPI_TAR - ss_DLA_CPI_RW + DLA_Z_BAR)) + (- RS + RS_US + PREM)/4 + SHK_L_S;
% or central bank manages the exchange rate to meet its inflation objective
% L_S = e1*L_S_TAR + (1-e1)*(L_S{+1} + ( - RS + RS_US + PREM)/4) + SHK_L_S;

% e1 captures for exchange rate persistency or central bank's FOREX interventions (the second equation);
% e1 varies between zero to 0.9 (very high control of the exchange rate); 

p.e1 = 0.6;

%% ER regime
p.h2 = 0; % 0 = float, 1=fix


%% 5. Monetary policy rule
% RS = g1*RS{-1} + (1-g1)*(RSNEUTRAL + g2*(DLA_CPI{+1} - D4L_CPI_TAR) + g3*L_GDP_GAP + g4*(DLA_S-DLA_S_TAR)) + SHK_RS;

% policy persistence; g1 varies from zero (no persistence in policy setting)
% to 0.8 ("wait and see" monetary policy)
p.g1 = 0.75;

% policy reactiveness (weight put on inflation by policy maker); g2 has no
% upper limit but must be always higher then zero/one (Taylor principle)
p.g2 = 1.25; 

% policy reactiveness (weight put on output gap by policy maker); g3 has no
% upper limit.It can be set to 0.
p.g3 = 0.25;

% policy reactiveness (weight put on nominal exchange rate depreciation by policy maker);
% g4 has no upper limit. It can be set to 0.
p.g4 = 0.2;

% in case of imperfect control of the domestic money market (use only if the central bank
% stabilieses exchange rate by interventions)

% RS = f1*(4*(L_S{+1} - L_S) + RS_US + PREM) + 
%      (1-f1)*(g1*RS{-1} + (1-g1)*(RSNEUTRAL + g2*(DLA_CPI{+1} - D4L_CPI_TAR)) + SHK_RS);

% degree to which the central bank does not control domestic money market
p.f1 = 0.2;

%% regime MP
p.h1                = 0; % 0=independent MP, 1=UIP implied rate

%% 7. Speed of convergence of last observed trend value to it calibrated value.
% Used for trend in GDP, real interest rate, real exchange rate,
% foreign real and nonimanl interest rate, foreign inflation, trend and gap in oil prices,
% and exchange rate target

p.rho_DLA_Z_BAR     = 0.75;
p.rho_PREM          = 0.75;
p.rho_DLA_GDP_BAR   = 0.85;
p.rho_L_GDP_US_GAP  = 0.85;
p.rho_RS_US         = 0.95;
p.rho_DLA_CPI_US    = 0.65;
p.rho_DLA_CPI_RU    = 0.65;
p.rho_DLA_RUB_USD   = 0.25; 
p.rho_DLA_RWOIL_BAR = 0.95;
p.rho_L_RWOIL_GAP   = 0.65;
p.rho_CR_PREM       = 0.65;

p.rho_DLA_S_TAR   = 0.35;
p.t2              = 0.25;
p.rho_D4L_CPI_TAR = 0.85;

p.w_ru = 0.26;

%% Inflation target and observed economic trends
% Domestic inflation target
p.ss_D4L_CPI_TAR   = 5;
% Foreign inflations trends/targets
p.ss_DLA_CPI_US    = 2;
% Calibrated wedge of real exchange rate appreciation
p.ss_DLA_Z_BAR     = -1;
% Calibrated wedge of growth in potential output
p.ss_DLA_GDP_BAR   = 7;
% Calibrated trend level of foreign real interest rate
p.ss_RR_US_BAR     = 0;

%% Model solving--a brief description of commands
% Command 'model' reads the text file 'model.mod' (contains the model's
% equations), assigns the parameters and trend values preset in the database
% 'p' (see readmodel) and transforms the model for the matrix algebra. 
% Transformed model is written in the object 'm'. 
m = model('model_rr_bar.model','linear',true,'assign',p);

% Command 'solve' takes the model saved in object 'm' and solves the model
% for its reduced form (Blanchard-Kahn algorithm). The reduced form is  
% written back in the object 'm'   
m = solve(m);

% Command 'sstate' takes the solved model in object 'm', calculates the model's
% steady-state and writes everything back in the object 'm'. Typing 'mss' in
% Matlab command window provides the steady-state values.
m = sstate(m);
mss = get(m,'sstate');
